@@ -1,7 +1,7 @@
 /*
  * This file is part of sidplayfp, a console SID player.
  *
- * Copyright 2011-2015 Leandro Nini
+ * Copyright 2011-2016 Leandro Nini
  * Copyright 2000-2001 Simon White
  *
  * This program is free software; you can redistribute it and/or modify
@@ -209,32 +209,27 @@ ConsolePlayer::ConsolePlayer (const char * const name) :
 
 IAudio* ConsolePlayer::getWavFile(const SidTuneInfo *tuneInfo)
 {
-    const char *title = m_outfile;
+    std::string title;
 
-    // Generate a name for the wav file
-    if (title == NULL)
+    if (m_outfile != NULL)
     {
+        title = m_outfile;
+    }
+    else
+    {
+        // Generate a name for the wav file
         title = tuneInfo->dataFileName();
-        const size_t length = strlen(title);
-        size_t i = length;
-        while (i > 0)
-        {
-            if (title[--i] == '.')
-                break;
-        }
-        if (!i) i = length;
 
-        std::string name(title, i);
+        title.erase(title.find_last_of('.'));
 
         // Change name based on subtune
         if (tuneInfo->songs() > 1)
         {
             std::ostringstream sstream;
             sstream << "[" << tuneInfo->currentSong() << "]";
-            name.append(sstream.str());
+            title.append(sstream.str());
         }
-        name.append(WavFile::extension());
-        title = name.c_str();
+        title.append(WavFile::extension());
     }
 
     return new WavFile(title);
@@ -499,21 +494,21 @@ bool ConsolePlayer::open (void)
     m_engine.mute(2, 2, vMute[8]);
 
     // As yet we don't have a required songlength
-    // so try the songlength database
+    // so try the songlength database or keep the default
     if (!m_timer.valid)
     {
-        const int_least32_t length = m_database.length (m_tune);
+        const int_least32_t length = m_database.length(m_tune);
         if (length > 0)
             m_timer.length = length;
     }
 
     // Set up the play timer
-    m_timer.stop  = 0;
-    m_timer.stop += m_timer.length;
+    m_timer.stop = m_timer.length;
 
     if (m_timer.valid)
     {   // Length relative to start
-        m_timer.stop += m_timer.start;
+        if (m_timer.stop > 0)
+            m_timer.stop += m_timer.start;
     }
     else
     {   // Check to make start time dosen't exceed end
